@@ -43,13 +43,15 @@ class CreateWeChatQrCodeHandler(ClientBaseHandler):
         :param page：跳转地址
         :param scene：参数
         :param width：宽度
+        :param no_limit_code：是否不限制小程序码（1-是0否）
         :return: 二进制流
         :last_editors: HuangJianYi
         """
         page = self.get_param("page", "pages/index/index")
         scene = self.get_param("scene", "a=1")
         width = self.get_param_int("width", 430)
-        invoke_result_data = WeChatHelper.create_qr_code(page, scene, width)
+        no_limit_code = self.get_param_int("no_limit_code", 1)
+        invoke_result_data = WeChatHelper.create_qr_code(page=page, scene=scene, width=width, no_limit_code=no_limit_code)
         self.set_header("Content-type", "image/png")
         if invoke_result_data.success == True:
             self.write(invoke_result_data.data)
