@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-11-18 17:42:55
+@LastEditTime: 2022-11-24 18:59:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -41,9 +41,12 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         dict_param = {}
-        dict_param["open_id"] = self.get_open_id()
-        if not dict_param["open_id"]:
-            dict_param["open_id"] = self.get_user_id()
+        if config.get_value("plat_type", 1) != 4: #如果是web站点，从cookie取
+            dict_param["open_id"] = self.get_open_id()
+            if not dict_param["open_id"]:
+                dict_param["open_id"] = self.get_user_id()
+        else:
+            dict_param["open_id"] = self.get_cooke_user_id()
         dict_param["nick_name"] = self.get_user_nick()
         dict_param["app_id"] = self.get_app_id()
         dict_param["source_type"] = self._request_source_type()
@@ -267,14 +270,15 @@ class FrameBaseHandler(BaseApiHandler):
         """
         self.http_response(self.json_dumps(rep_dic))
 
-    def response_common(self, success=True, data=None, error_code="", error_message=""):
+    def response_common(self, success=True, data=None, error_code="", error_message="", is_close_encrypt=False):
         """
         :description: 输出公共json模型
         :param success: 布尔值，表示本次调用是否成功
         :param data: 类型不限，调用成功（success为true）时，服务端返回的数据
         :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
         :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
-        :return: 将dumps后的数据字符串返回给客户端
+        :param is_close_encrypt: 是否关闭输出加密（True-是 False-否）
+        :return: 将dumps后的数据字符串返回给客户端   
         :last_editors: HuangJianYi
         """
         if hasattr(data, '__dict__'):
@@ -286,20 +290,23 @@ class FrameBaseHandler(BaseApiHandler):
             template_value['data'] = data
         else:
             if self.is_api_encrypt() == True:
-                dv = SevenHelper.get_random(16)
-                encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-                if self.get_argument("app_id", "", strip=True):
-                    app_id = self.get_argument("app_id", "", strip=True)
+                if is_close_encrypt == False:
+                    dv = SevenHelper.get_random(16)
+                    encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+                    if self.get_argument("app_id", "", strip=True):
+                        app_id = self.get_argument("app_id", "", strip=True)
+                    else:
+                        app_id = self.get_argument("source_app_id", "", strip=True)
+                    if not app_id:
+                        app_id = config.get_value("app_id")
+                    password = str(encrypt_key).replace("1", "l")
+                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+                    template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
+                    template_value['dv'] = dv
+                    if config.get_value("log_plain",True) == True:
+                        self.logging_link_info(f"plain_response_data:{self.json_dumps(data)}")
                 else:
-                    app_id = self.get_argument("source_app_id", "", strip=True)
-                if not app_id:
-                    app_id = config.get_value("app_id")
-                password = str(encrypt_key).replace("1", "l")
-                iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
-                template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
-                template_value['dv'] = dv
-                if config.get_value("log_plain",True) == True:
-                    self.logging_link_info(f"plain_response_data:{self.json_dumps(data)}")
+                    template_value['data'] = data
             else:
                 template_value['data'] = data
         template_value['error_code'] = "error" if not error_code and success == False else error_code
@@ -316,22 +323,24 @@ class FrameBaseHandler(BaseApiHandler):
 
         self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
 
-    def response_json_success(self, data=None):
+    def response_json_success(self, data=None, is_close_encrypt=False):
         """
         :description: 通用成功返回json结构
         :param data: 返回结果对象，即为数组，字典
+        :param is_close_encrypt: 是否关闭输出加密（True-是 False-否）
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJianYi
         """
-        self.response_common(data=data)
+        self.response_common(data=data,is_close_encrypt=is_close_encrypt)
 
-    def response_json_error(self, error_code="", error_message="", data=None, log_type=0):
+    def response_json_error(self, error_code="", error_message="", data=None, log_type=0, is_close_encrypt=False):
         """
         :description: 通用错误返回json结构
         :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
         :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
         :param data: 返回结果对象，即为数组，字典
         :param log_type: 日志记录类型（0-不记录，1-info，2-error）
+        :param is_close_encrypt: 是否关闭输出加密（True-是 False-否）
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJianYi
         """
@@ -339,7 +348,7 @@ class FrameBaseHandler(BaseApiHandler):
             self.logging_link_info(f"{error_code}\n{error_message}\n{data}\n{self.request}")
         elif log_type == 2:
             self.logging_link_error(f"{error_code}\n{error_message}\n{data}\n{self.request}")
-        self.response_common(False, data, error_code, error_message)
+        self.response_common(False, data, error_code, error_message, is_close_encrypt)
 
     def response_json_error_params(self):
         """
