@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-11-23 10:50:09
+@LastEditTime: 2022-11-24 09:33:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -89,6 +89,8 @@ class WeChatHelper:
                 invoke_result_data.error_message = response_data["errmsg"]
                 return invoke_result_data
             invoke_result_data.data = response_data
+            if invoke_result_data.data.__contains__("nickname"):
+                invoke_result_data.data["nickname"] = invoke_result_data.data["nickname"].encode('ISO-8859-1').decode('utf-8')
             return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【get_web_authorize_userinfo】" + traceback.format_exc())
@@ -431,17 +433,21 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def create_qr_code(self, page, scene="a=1", width=430, app_id="", app_secret=""):
+    def create_qr_code(self, page, scene="a=1", width=430, app_id="", app_secret="", no_limit_code=True):
         """
-        :description:获取小程序/小游戏的二维码
+        :description:获取小程序/小游戏的二维码（注意：接口只能生成已发布的小程序的二维码。开发版的带参二维码可以在开发者工具预览时生成）
         :param page: 页面 page，例如 pages/index/index，根路径前不要填加 /，不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面
         :param scene: 最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）
         :param width: 二维码的宽度，单位 px，最小 280px，最大 1280px
         :param app_id:app_id
         :param app_secret:app_secret
+        :param no_limit_code:是否无限制小程序码
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        
         invoke_result_data = InvokeResultData()
         redis_init = SevenHelper.redis_init(decode_responses=False)
         redis_key = "wechat_qr_code:" + CryptoHelper.md5_encrypt(f"{page}_{scene}")
@@ -463,11 +469,15 @@ class WeChatHelper:
         access_token = invoke_result_data.data
         response = ""
         try:
-            requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
             headers = {"Content-type": "application/json"}
-            param = {"scene": scene, "page": page, "width": width, "auto_color": True, "is_hyaline": False}
-            response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+            if no_limit_code == True:
+                requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
+                param = {"scene": scene, "page": page, "width": width}
+            else:
+                requset_url = 'https://api.weixin.qq.com/cgi-bin/wxaapp/createwxaqrcode?access_token=' + access_token
+                param = {"path": page, "width": width}
             try:
+                response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
                 response_data = SevenHelper.json_loads(response.text)
                 if response_data.__contains__("errcode") and response_data["errcode"] != 0:
                     invoke_result_data.success = False
