@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-08-25 16:15:34
+@LastEditTime: 2022-11-24 17:21:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -279,17 +279,18 @@ class StatConsoleModel():
                     create_year_int = int(create_date.strftime('%Y'))
                     field_name = stat_queue_dict["key_name"]
 
-                    stat_log = StatLog()
-                    stat_log.app_id = stat_queue_dict["app_id"]
-                    stat_log.act_id = stat_queue_dict["act_id"]
-                    stat_log.module_id = stat_queue_dict["module_id"]
-                    stat_log.user_id = stat_queue_dict["user_id"]
-                    stat_log.open_id = stat_queue_dict["open_id"]
-                    stat_log.key_name = field_name
-                    stat_log.key_value = stat_queue_dict["key_value"]
-                    stat_log.create_day = create_day_int
-                    stat_log.create_month = create_month_int
-                    stat_log.create_date = create_date
+                    stat_user_log = StatUserLog()
+                    stat_user_log.app_id = stat_queue_dict["app_id"]
+                    stat_user_log.act_id = stat_queue_dict["act_id"]
+                    stat_user_log.module_id = stat_queue_dict["module_id"]
+                    stat_user_log.user_id = stat_queue_dict["user_id"]
+                    stat_user_log.open_id = stat_queue_dict["open_id"]
+                    stat_user_log.key_name = field_name
+                    stat_user_log.key_value = stat_queue_dict["key_value"]
+                    stat_user_log.request_code = stat_queue_dict.get("request_code","")
+                    stat_user_log.create_day = create_day_int
+                    stat_user_log.create_month = create_month_int
+                    stat_user_log.create_date = create_date
 
                     stat_report_condition = "act_id=%s and module_id=%s and create_day=%s and user_id=%s"
                     stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], create_day_int, stat_queue_dict["user_id"]]
@@ -312,7 +313,7 @@ class StatConsoleModel():
                     db_transaction.begin_transaction()
                     key_value = stat_queue_dict["key_value"]
                     stat_user_report_model.update_table(f"{field_name}={field_name}+{key_value}", stat_report_condition, params=stat_report_param)
-                    stat_user_log_model.add_entity(stat_log)
+                    stat_user_log_model.add_entity(stat_user_log)
                     result,message = db_transaction.commit_transaction(True)
                     if result == False:
                         raise Exception("执行事务失败", message)
