@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2022-11-08 11:10:37
+@LastEditTime: 2022-11-23 13:51:11
 @LastEditors: HuangJianYi
 @Description: 操作日志相关处理业务模型
 """
@@ -208,7 +208,7 @@ class OperateBaseModel():
                     else:
                         config_json = SevenHelper.json_loads(operation_config["config_json"]) if operation_config["config_json"] else {}
                         config_fields =  query(config_json).where(lambda x: x["field"] == key).first_or_default(None)
-                    if not config_fields:
+                    if not config_fields or config_fields.get("is_show",1) == 0:
                         continue
                     old_value = str(operation_log["detail"].get(key, ""))
                     new_value = str(operation_log["update_detail"].get(key, ""))
